/*
 *  This file is part of the KDE libraries
 *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
 *
 *  $Id: kprintdialogpage.cpp,v 1.5 2001/08/27 13:54:50 goffioul Exp $
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License version 2 as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 *  Boston, MA 02111-1307, USA.
 **/

#include "kprintdialogpage.h"

KPrintDialogPage::KPrintDialogPage(QWidget *parent, const char *name)
: QWidget(parent,name), m_printer(0), m_driver(0), m_ID(0), m_onlyreal(false)
{
}

KPrintDialogPage::KPrintDialogPage(KMPrinter *pr, DrMain *dr, QWidget *parent, const char *name)
: QWidget(parent,name), m_printer(pr), m_driver(dr), m_ID(0), m_onlyreal(false)
{
}

KPrintDialogPage::~KPrintDialogPage()
{
}

void KPrintDialogPage::setOptions(const QMap<QString,QString>&)
{
}

void KPrintDialogPage::getOptions(QMap<QString,QString>&, bool)
{
}

bool KPrintDialogPage::isValid(QString&)
{
	return true;
}
#include "kprintdialogpage.moc"
